import greenfoot.*;  // (World, Actor, GreenfootImage, Greenfoot and MouseInfo)

/**
 * Representa una carta o naipe de una baraja francesa. Una carta tiene un valor (A, 2, 3, ..., Q, K)
 * de un palo (diamantes, corazones, picas o treboles). Una carta en la mesa de juego puede estar
 * revelada, en cuyo caso el jugador puede ver su valor, o puede estar oculta, en cuyo caso el
 * jugador solo ve su fondo
 */
public class Carta extends Actor
{
    /** 
     * El palo de la baraja al que pertenece esta carta. Es uno de los textos:
     * "diamantes", "corazones", "picas", o "treboles"
     */
    private String palo;
    
    /** El valor de la carta: un texto entre "A", "2", ..., "Q", y "K" **/
    private String valor;
    
    /** La imagen exclusiva para esta carta **/
    private GreenfootImage imagen;
    
    /** La imagen de fondo es la misma para todas las cartas de la baraja **/
    private static GreenfootImage fondo = new GreenfootImage("fondo.png");
    
    /**
     * Construye una carta de la baraja. Por ejemplo si se quiere crear el as de
     * treboles, invoque: new Carta("treboles", "A");
     * 
     * @param palo Uno de los textos: "diamantes", "corazones", "picas", o "treboles"
     * @param valor Uno de los textos: "A", "2", "3", "4", "5", "6", "7", "8", "9", "10", "J", "Q", "K"
     */
    public Carta(String palo, String valor)
    {
        this.palo = palo;
        this.valor = valor;
        this.imagen = new GreenfootImage(palo + "-" + valor + ".png");
    }
    
    /** 
     * Retorna el palo de la baraja al que pertenece esta carta. Es uno de los textos:
     * "diamantes", "corazones", "picas", o "treboles"
     */
    public String palo()
    {
        return palo;
    }
    
    /** Retorna el valor de la carta: un texto entre "A", "2", ..., "Q", y "K" **/
    public String valor()
    {
        return valor;
    }
    
    /**
     * Hace que la carta reaccione a los eventos del raton. Hacer clic sobre
     * una carta es una indicacion de que debe revelarse
     */
    public void act() 
    {
        // Determinar si el puntero del raton esta sobre esta carta
        MouseInfo mouseInfo = Greenfoot.getMouseInfo();
        if ( mouseInfo != null && mouseInfo.getActor() == this )
        {
            // Si se hizo clic sobre esta carta, revelarla
            if ( mouseInfo.getClickCount() == 1 )
            {
                revelar();
            }
            /*else if ( mouseInfo.getButton() == 1 )
            {
                this.setLocation(mouseInfo.getX(), mouseInfo.getY());
            }*/
        }
    }
    
    /**
     * Revela el valor de la carta en la pantalla, de tal forma que el jugador pueda
     * ver su palo y valor en lugar de su imagen de fondo
     */
    public void revelar()
    {
        setImage(imagen);
    }
    
    /** Oculta el valor de la carta mostrando su fondo en la pantalla */
    public void ocultar()
    {
        setImage(fondo);
    }
}
